import React, { useEffect } from 'react';
import { Layout, Spin } from 'antd';
import { useLocation, Outlet } from "react-router-dom";
import { useModel } from '@/store';
import useRoute from '@/utils/hooks/useRoute';
import RequireLogin from './components/RequireLogin';
import SiderBar from './components/SiderBar';
import Header from './components/Header';
import Container from './components/Container';
import HtmlTitle from './components/HtmlTitle';

import './style.less';

export default (props) => {
  const { theme } = useModel('system');
  const { user, menus } = useModel('user');
  const location = useLocation();
  const { meta } = useRoute() || {};
  const { noLayout = false, noSiderBar = false, noFooter = false } = meta || {};

  return (
    <Spin spinning={!user} size="large">
      <HtmlTitle />
      <RequireLogin>
        {
          noLayout
            ? <Outlet />
            : (
              <Layout style={{ height: '100vh' }}>
                <Header theme={theme} user={user} />
                <Layout style={{ height: 'calc(100vh - var(--header-height))' }}>
                  { !noSiderBar && <SiderBar theme={theme} menus={menus} location={location} /> }
                  <Container location={location} noFooter={noFooter} />
                </Layout>
              </Layout>
            )
        }
      </RequireLogin>
    </Spin>
  );
}
