import React from 'react';
import Page from '@/components/Page';
import { useNavigate, useSearchParams } from 'react-router-dom';
import { queryTable, queryDict } from "@/utils/request";
import { ProTable } from "@ant-design/pro-components";
import { Button, notification } from "antd";
import { getTaCheck } from '@/service/tacheck';
import { getTaCheckAnswerDetail, exportTaCheckAnswerDetail } from '@/service/tacheckanswer';
import useBool from '@/utils/hooks/useBool';

const getCheck = queryDict(getTaCheck, { labelKey: 'title', valueKey: 'checkId' });
const getAnswer = queryTable(getTaCheckAnswerDetail);

const addOnParams = { itemType: 'survey' };

export default (props) => {
  const [loading, startLoading, stopLoading] = useBool();
  const paramsRef = React.useRef();
  const [notificationApi, contextHolder] = notification.useNotification();
  const [params] = useSearchParams();
  const answerId = params.get('answerId');
  const itemType = params.get('itemType');

  const columns = [
    // {
    //   title: "模拟测评",
    //   dataIndex: "checkId",
    //   valueType: 'select',
    //   request: getCheck,
    //   hideInTable: true,
    //   formItemProps: {
    //     rules: [
    //       { required: true, message: '请选择模拟测评' }
    //     ]
    //   }
    // },
    {
      title: "社区",
      dataIndex: "communityName",
    },
    // {
    //   title: "小区",
    //   dataIndex: "addr",
    // },
    {
      title: "问题",
      dataIndex: "quTitle",
      hideInSearch: true,
    },
    {
      title: "答案",
      dataIndex: "answer",
      hideInSearch: true,
    },
    {
      title: "得分",
      dataIndex: "score",
      hideInSearch: true,
    },
    // {
    //   title: "答题时间",
    //   dataIndex: "createDate",
    //   valueType: 'date',
    //   hideInSearch: true,
    // },
    // {
    //   title: "答题人",
    //   dataIndex: "userName",
    //   hideInSearch: true,
    // },
    // {
    //   title: "受访者性别",
    //   dataIndex: "sex",
    //   hideInSearch: true,
    // },
    // {
    //   title: "年龄段",
    //   dataIndex: "age",
    //   hideInSearch: true,
    // }
  ]

  const beforeSearchSubmit = (params) => {
    paramsRef.current = params;
    return params;
  }

  const onExport = () => {
    startLoading();
    exportTaCheckAnswerDetail({
      answerId,
      itemType,
    }).then(() => {
      stopLoading();
    }).catch(() => {
      stopLoading();
    });
  }

  return (
    <Page back>
      {contextHolder}
      <ProTable
        rowKey="answerItemId"
        // manualRequest
        search={false}
        columns={columns}
        request={getAnswer}
        params={{ answerId, itemType }}
        beforeSearchSubmit={beforeSearchSubmit}
        form={{ ignoreRules: false }}
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
            loading={loading}
            onClick={onExport}
          >
            导出
          </Button>,
        ]}
      />
    </Page>
  )
}
