import React, { useState } from 'react';
import { Card } from 'antd';
import * as echarts from 'echarts/core';
import dayjs from 'dayjs';
import Chart from '@/components/chart';
import { getStatIssue } from "@/service/stat";
import RangeDate from './RangeDate';

export default React.forwardRef((props, ref) => {
  const [option, setOption] = useState({});

  const [condition, setCondition] = useState();

  React.useEffect(() => {
    if (!condition) return;
    getStatIssue(condition).then((res) => {
      setOption({
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              backgroundColor: '#0A9071'
            }
          }
        },
        grid: {
          left: '3%',
          bottom: '3%',
          width: '92%',
          height: '90%',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            boundaryGap: false,
            data: res.map(x => x.name)
          }
        ],
        yAxis: [
          {
            type: 'value',
            minInterval: 1
          }
        ],
        series: [
          {
            type: 'line',
            stack: 'Total',
            smooth: true,
            lineStyle: {
              width: 0
            },
            showSymbol: false,
            areaStyle: {
              opacity: 1,
              color: new echarts.graphic.LinearGradient(0, 0, 0, 1.1, [
                {
                  offset: 0,
                  color: '#0A9071'
                },
                {
                  offset: 1,
                  color: '#FFF'
                }
              ])
            },
            emphasis: {
              focus: 'series'
            },
            data: res.map(x => x.value)
          }
        ]
      })
    })
  }, [condition]);

  //子组件通过点击或自定义传过来的值变成参数条件set给condition
  const onChange = (dt, typ) => {
    if (typ == 1) {
      setCondition({
        num: 7,
        statType: 'issue_daily',
        startDate: dt[0].format('YYYY-MM-DD'),
        endDate: dt[1].format('YYYY-MM-DD'),
      })
    } else if (typ == 2) {
      setCondition({
        num: dt[0].daysInMonth(),
        statType: 'issue_daily',
        startDate: dt[0].format('YYYY-MM-DD'),
        endDate: dt[1].format('YYYY-MM-DD'),
      })
    } else if (typ == 3) {
      setCondition({
        num: 12,
        statType: 'issue_monthly',
        startDate: dt[0].format('YYYY-MM'),
        endDate: dt[1].format('YYYY-MM'),
      })
    } else {
      setCondition({
        num: dayjs(dt[1]).diff(dt[0], 'day'),
        statType: 'issue_daily',
        startDate: dt[0].format('YYYY-MM-DD'),
        endDate: dt[1].format('YYYY-MM-DD'),
      })
    }

    // console.log('dt天数', dayjs(dt[1]).diff(dt[0], 'day'));
  }

  return (
    <Card title="上报统计" extra={<RangeDate onChange={onChange} />}>
      <Chart option={option} style={props.style}></Chart>
    </Card>
  )
});